<template>
  <div class="echart" ref="chart"></div>
</template>

<script>
import * as echarts from "echarts"
import { countDataVisit } from "@/api/screen.js"
export default {
  data() {
    return {}
  },
  mounted() {
    this.initChart()
  },
  methods: {
    async initChart() {
      const res = await countDataVisit()
      let dataPie = [
        {
          value: 410,
          name: "企业",
        },
        {
          value: 380,
          name: "政府",
        },
        {
          value: 50,
          name: "个人",
        },
        {
          value: 50,
          name: "个人1",
        },
        {
          value: 50,
          name: "个人2",
        },
        {
          value: 50,
          name: "个人3",
        },
        {
          value: 50,
          name: "个人4",
        },
        {
          value: 50,
          name: "个人5",
        },
      ]
      let count = 0
      if (res.code == 200) {
        dataPie = res.result.map(item => {
          count += item.count
          return {
            value: item.count,
            name: item.modular1,
          }
        })
      }

      let colorPie = ["#5f6d86", "#0b2036", "#002e49"]
      let colorWrap = [
        "#006CFF",
        "#3087d6",
        "#afe1ff",
        "#4be1ff",
        "#5C7AAE",
        "#15D0FF",
        "#7f44bb",
        "#9BD3FF",
      ]
      let baseDataPie = [],
        baseDataWrap = []
      for (var i = 0; i < dataPie.length; i++) {
        baseDataPie.push({
          value: dataPie[i].value,
          name: dataPie[i].name,
          itemStyle: {
            normal: {
              borderWidth: 0.5,
              borderColor: "#5f6d86",
            },
          },
        })
        baseDataWrap.push(
          {
            value: dataPie[i].value,
            name: dataPie[i].name,
            itemStyle: {
              normal: {
                color: colorWrap[i],
                borderWidth: 4,
                borderColor: colorWrap[i],
                shadowBlur: 5,
                shadowColor: "rgba(48, 135, 214, 0.3)",
              },
            },
          },
          {
            value: 30,
            name: "",
            itemStyle: {
              normal: {
                color: "transparent",
                borderWidth: 20,
                borderColor: "transparent",
              },
            },
          }
        )
      }

      let option = {
        backgroundColor: "transparent",
        title: {
          text: "服务类型总数量",
          subtext: count,
          textStyle: {
            color: "#fff",
            fontSize: 12,
          },
          subtextStyle: {
            align: "center",
            fontSize: 20,
            color: ["#fff"],
            fontWeight: 400,
            fontFamily: "YouSheBiaoTiHei",
          },
          x: "20%",
          y: "40%",
        },
        // tooltip: {
        //   show: true,
        //   // trigger: "item",
        //   // formatter: "{a}：{b} <br/>占比：{d}%",
        // },
        legend: {
          data: dataPie,
          icon: "vertical",
          right: "1%",
          top: "10%",
          orient: "vertical",
          itemGap: 7,
          itemWidth: 12,
          itemHeight: 3,

          formatter: function (name) {
            let target
            for (let i = 0; i < dataPie.length; i++) {
              if (dataPie[i].name === name) {
                target = dataPie[i].value
              }
            }
            let arr = `${name} |${target}`
            return arr
          },
          textStyle: {
            lineHeight: 15,
            color: "#9ed2f5",
          },
        },
        grid: {
          left: "1%", // 与容器左侧的距离
          right: "1%", // 与容器右侧的距离
          top: "1%", // 与容器顶部的距离
          bottom: "1%", // 与容器底部的距离
        },
        series: [
          {
            name: "",
            type: "pie",
            clockWise: false, //顺时加载
            hoverAnimation: false, //鼠标移入变大
            center: ["30%", "50%"],
            radius: ["60%", "65%"],
            tooltip: {
              show: false,
            },
            label: {
              normal: {
                show: false,
              },
            },
            data: baseDataWrap,
          },
          {
            name: "服务类型",
            type: "pie",
            color: "#5F6D86",
            selectedMode: "single",
            center: ["30%", "50%"],
            radius: ["73%", "74%"],
            hoverAnimation: false,
            label: {
              normal: {
                show: false,
              },
            },

            data: baseDataPie,
          },
        ],
      }
      const chart = echarts.init(this.$refs.chart)

      chart.setOption(option)
      window.addEventListener("resize", function () {
        chart.resize()
      })
    },
  },
}
</script>

<style lang="scss" scoped>
.echart {
  width: 100%;
  height: 100%;
}
</style>
